@@ -176,8 +176,8 @@ plot_modeltime_forecast_multi <- function(.data,
                                  alpha    = .conf_interval_alpha,
                                  # color    = .conf_interval_fill,
                                  # na.rm    = TRUE, # causes error
-                                 linetype = 0,
-                                 data = data_prepared %>% dplyr::filter(!is.na(.conf_lo))
+                                 # data = data_prepared %>% dplyr::filter(!is.na(.conf_lo))
+                                 linetype = 0
                                 )
 
 
