@@ -1,3 +1,5 @@
+# MODELTIME REFIT ----
+
 #' Refit one or more trained models to new data
 #'
 #' This is a wrapper for `fit()` that takes a
@@ -89,14 +91,6 @@ modeltime_refit <- function(object, data, control = NULL, ...) {
     UseMethod("modeltime_refit", object)
 }
 
-# #' @export
-# #' @rdname modeltime_refit
-# modeltime_refit_xy <- function(object, x, y, control = NULL, ...) {
-#     UseMethod("modeltime_refit_xy", object)
-# }
-
-# MODELTIME ----
-
 #' @export
 modeltime_refit.mdl_time_tbl <- function(object, data, control = NULL, ...) {
 
@@ -226,41 +220,10 @@ mdl_time_refit.model_fit <- function(object, data, control = NULL, ...) {
 
     model_spec <- object$spec
 
-    # Deterimine Interface
-    fit_interface <- object$spec$method$fit$interface
+    form <- object %>% pull_parsnip_preprocessor()
 
-    if (fit_interface == "formula") {
-
-        # Formula interface includes preprocessing internally to the object's fit method
-        # - Need to extract formula using find_formula()
-
-        form <- object$fit %>% find_formula()
-        if (is.null(form)) {
-            rlang::abort("Could not 'refit()' model. The model formula could not be located. Consider using a 'workflow()' instead to ensure model refitting is possible.")
-        }
-
-        ret <- model_spec %>%
-            parsnip::fit(form, data = data, control = control, ...)
-
-    } else {
-
-        # fit_interface is either "data.frame" or "matrix"
-
-        # check for formula in object$peproc$terms
-        if ("terms" %in% names(object$preproc)) {
-            if (inherits(object$preproc$terms, "formula")) {
-
-                form <- stats::formula(object$preproc$terms)
-
-                ret <- model_spec %>%
-                    fit(form, data = data)
-            }
-        } else {
-            rlang::abort("Could not 'refit()' model. The model formula could not be located. Consider using a 'workflow()' instead to ensure model refitting is possible.")
-
-        }
-
-    }
+    ret <- model_spec %>%
+        parsnip::fit(form, data = data, control = control, ...)
 
     return(ret)
 
@@ -268,30 +231,30 @@ mdl_time_refit.model_fit <- function(object, data, control = NULL, ...) {
 
 
 
-#' # REFIT XY ----
-#'
-#' #' @export
-#' mdl_time_refit_xy.workflow <- function(object, x, y, control = NULL, ...) {
-#'     rlang::abort("Using 'mdl_time_refit_xy()' on a workflow object is not allowed. Try using 'modeltime_refit()'.")
-#' }
-#'
-#' #' @export
-#' mdl_time_refit_xy.model_fit <- function(object, x, y, control = NULL, ...) {
-#'
-#'     if (is.null(control)) {
-#'         control <- parsnip::control_parsnip()
-#'     }
-#'
-#'     model_spec <- object$spec
-#'
-#'     ret <- model_spec %>%
-#'         fit_xy(x = x, y = y, control = control, ...)
-#'
-#'     return(ret)
-#'
-#' }
-#'
-#' #' @export
-#' mdl_time_refit_xy.default <- function(object, x, y, control = NULL, ...) {
-#'     rlang::abort(paste0("No method for class '", class(object)[1], "'."))
-#' }
+# # REFIT XY ----
+#
+# #' @export
+# mdl_time_refit_xy.workflow <- function(object, x, y, control = NULL, ...) {
+#     rlang::abort("Using 'mdl_time_refit_xy()' on a workflow object is not allowed. Try using 'modeltime_refit()'.")
+# }
+#
+# #' @export
+# mdl_time_refit_xy.model_fit <- function(object, x, y, control = NULL, ...) {
+#
+#     if (is.null(control)) {
+#         control <- parsnip::control_parsnip()
+#     }
+#
+#     model_spec <- object$spec
+#
+#     ret <- model_spec %>%
+#         fit_xy(x = x, y = y, control = control, ...)
+#
+#     return(ret)
+#
+# }
+#
+# #' @export
+# mdl_time_refit_xy.default <- function(object, x, y, control = NULL, ...) {
+#     rlang::abort(paste0("No method for class '", class(object)[1], "'."))
+# }
