@@ -3,7 +3,7 @@
 # they are already in the parsnip model database. We'll exclude them from
 # coverage stats for this reason.
 
-# nocov
+# nocov start
 
 
 make_prophet_boost <- function() {
@@ -16,6 +16,8 @@ make_prophet_boost <- function() {
     # * Model ----
     parsnip::set_model_engine("prophet_boost", mode = "regression", eng = "prophet_xgboost")
     parsnip::set_dependency("prophet_boost", eng = "prophet_xgboost", pkg = "prophet")
+    parsnip::set_dependency("prophet_boost", eng = "prophet_xgboost", pkg = "xgboost")
+    parsnip::set_dependency("prophet_boost", eng = "prophet_xgboost", pkg = "modeltime")
 
     # * Args - Prophet ----
     parsnip::set_model_arg(
@@ -30,9 +32,45 @@ make_prophet_boost <- function() {
     parsnip::set_model_arg(
         model        = "prophet_boost",
         eng          = "prophet_xgboost",
-        parsnip      = "num_changepoints",
+        parsnip      = "changepoint_num",
         original     = "n.changepoints",
-        func         = list(pkg = "modeltime", fun = "num_changepoints"),
+        func         = list(pkg = "modeltime", fun = "changepoint_num"),
+        has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+        model        = "prophet_boost",
+        eng          = "prophet_xgboost",
+        parsnip      = "changepoint_range",
+        original     = "changepoint.range",
+        func         = list(pkg = "modeltime", fun = "changepoint_range"),
+        has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+        model        = "prophet_boost",
+        eng          = "prophet_xgboost",
+        parsnip      = "seasonality_yearly",
+        original     = "yearly.seasonality",
+        func         = list(pkg = "modeltime", fun = "seasonality_yearly"),
+        has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+        model        = "prophet_boost",
+        eng          = "prophet_xgboost",
+        parsnip      = "seasonality_weekly",
+        original     = "weekly.seasonality",
+        func         = list(pkg = "modeltime", fun = "seasonality_weekly"),
+        has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+        model        = "prophet_boost",
+        eng          = "prophet_xgboost",
+        parsnip      = "seasonality_daily",
+        original     = "daily.seasonality",
+        func         = list(pkg = "modeltime", fun = "seasonality_daily"),
         has_submodel = FALSE
     )
 
@@ -72,6 +110,24 @@ make_prophet_boost <- function() {
         has_submodel = FALSE
     )
 
+    parsnip::set_model_arg(
+        model        = "prophet_boost",
+        eng          = "prophet_xgboost",
+        parsnip      = "logistic_cap",
+        original     = "logistic_cap",
+        func         = list(pkg = "modeltime", fun = "logistic_cap"),
+        has_submodel = FALSE
+    )
+
+    parsnip::set_model_arg(
+        model        = "prophet_boost",
+        eng          = "prophet_xgboost",
+        parsnip      = "logistic_floor",
+        original     = "logistic_floor",
+        func         = list(pkg = "modeltime", fun = "logistic_floor"),
+        has_submodel = FALSE
+    )
+
     # * Args - Xgboost ----
 
     parsnip::set_model_arg(
